GroundAsset

Struct GroundAsset 

pub struct GroundAsset {
    pub latitude_deg: f64,
    pub longitude_deg: f64,
    pub height_km: f64,
    pub latitude_rate_deg_s: f64,
    pub longitude_rate_deg_s: f64,
    pub height_rate_km_s: f64,
    pub epoch: Epoch,
    pub frame: Frame,
    pub stm: Option<OMatrix<f64, Const<6>, Const<6>>>,
}
Represents a ground position/nav/timing receiver, e.g. a customer Note that we rebuild the Location structure from ANISE but without a terrain mask because the mask is not copyable and this PNTRx must be copyable to implement State.

Fields

latitude_deg: f64longitude_deg: f64height_km: f64latitude_rate_deg_s: f64longitude_rate_deg_s: f64height_rate_km_s: f64epoch: Epochframe: Frame

Frame on which this location rests

stm: Option<OMatrix<f64, Const<6>, Const<6>>>

Implementations

Source

impl GroundAsset

pub fn from_fixed( latitude_deg: f64, longitude_deg: f64, height_km: f64, epoch: Epoch, frame: Frame, ) -> Self

pub fn with_velocity_sez_m_s( self, vel_s_m_s: f64, vel_e_m_s: f64, vel_z_m_s: f64, ) -> Result<Self, Box<dyn Error>>

pub fn to_location(&self) -> Location

pub fn velocity_sez_m_s(&self) -> Result<OVector<f64, Const<3>>, PhysicsError>

Compute the velocity in m/s in the SEZ frame from the state data stored in latitude deg/s, longitude deg/s, and height in km/s for integration of EOMs

pub fn geodetic_to_cartesian_jacobian( &self, ) -> Result<Matrix6<f64>, PhysicsError>

pub fn great_circle_distance_km( &self, other: &Self, ) -> Result<f64, PhysicsError>

Computes the great circle (Haversine) distance between this asset and another in kilometers.

Note: This assumes a perfectly spherical body using the frame’s mean equatorial radius. It does not account for the ellipsoidal oblateness or the height_km of either asset.